@@ -1,8 +1,10 @@
 # Licensed under the MIT License, see LICENSE for details.
-
+"""Common distance functions.
+"""
 import torch
+T = torch.Tensor
 
-def pairwise_l2_squared(x, y):
+def pairwise_l2_squared(x: T, y: T) -> T:
     """Computes the pairwise distance matrix between x and y using the
     quadratic expansion. This limits the memory cost to the detriment of compute
     accuracy.
@@ -13,9 +15,9 @@ def pairwise_l2_squared(x, y):
     return torch.clamp(dist, 0.0, torch.inf)
 
 
-def pairwise_l2_squared_exact(x, y):
+def pairwise_l2_squared_exact(x: T, y: T) -> T:
     """Computes the pairwise distance matrix between x and y. This formula
-    incurs a high memory use.
+    incurs a high memory cost.
     """
     n = x.size(1)
     m = y.size(1)
